@@ -1,4 +1,4 @@
-from ts_app.dashboard import app
+from ts_app.dash_app import app
 
 if __name__ == "__main__":
     app.run_server(debug=True)
