@@ -1,7 +1,7 @@
 import argparse
 
 
-def process_cli_args():
+def process_cli_args() -> None:
     """Create arguments and collect input from the command line."""
     parser = argparse.ArgumentParser(
         prog="ts_app",
@@ -19,7 +19,7 @@ def process_cli_args():
     )
     parser.add_argument(
         "--host",
-        default="0.0.0.0",
+        default="localhost",
         help="A host-name or IP address (default: %(default)r).",
     )
     parser.add_argument(
